CreateBackupChannelRequest

Struct CreateBackupChannelRequest 

#[non_exhaustive]
pub struct CreateBackupChannelRequest { pub parent: String, pub backup_channel: Option<BackupChannel>, pub backup_channel_id: String, /* private fields */ }
Request message for CreateBackupChannel.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. The location within which to create the BackupChannel. Format: projects/*/locations/*

backup_channel: Option<BackupChannel>

Required. The BackupChannel resource object to create.

backup_channel_id: String

Optional. The client-provided short name for the BackupChannel resource. This name must:

  • be between 1 and 63 characters long (inclusive)
  • consist of only lower-case ASCII letters, numbers, and dashes
  • start with a lower-case letter
  • end with a lower-case letter or number
  • be unique within the set of BackupChannels in this location If the user does not provide a name, a uuid will be used as the name.

Implementations

Source

impl CreateBackupChannelRequest

pub fn new() -> Self

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = CreateBackupChannelRequest::new().set_parent("example");
pub fn set_backup_channel<T>(self, v: T) -> Self
where T: Into<BackupChannel>,

Sets the value of backup_channel.

Example
use google_cloud_gkebackup_v1::model::BackupChannel;
let x = CreateBackupChannelRequest::new().set_backup_channel(BackupChannel::default()/* use setters */);
pub fn set_or_clear_backup_channel<T>(self, v: Option<T>) -> Self
where T: Into<BackupChannel>,

Sets or clears the value of backup_channel.

Example
use google_cloud_gkebackup_v1::model::BackupChannel;
let x = CreateBackupChannelRequest::new().set_or_clear_backup_channel(Some(BackupChannel::default()/* use setters */));
let x = CreateBackupChannelRequest::new().set_or_clear_backup_channel(None::<BackupChannel>);
pub fn set_backup_channel_id<T: Into<String>>(self, v: T) -> Self

Sets the value of backup_channel_id.

Example
let x = CreateBackupChannelRequest::new().set_backup_channel_id("example");