#[non_exhaustive]pub struct CreateRestoreChannelRequest {
pub parent: String,
pub restore_channel: Option<RestoreChannel>,
pub restore_channel_id: String,
/* private fields */
}Expand description
Request message for CreateRestoreChannel.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The location within which to create the RestoreChannel.
Format: projects/*/locations/*
restore_channel: Option<RestoreChannel>Required. The RestoreChannel resource object to create.
restore_channel_id: StringOptional. The client-provided short name for the RestoreChannel resource. This name must:
- be between 1 and 63 characters long (inclusive)
- consist of only lower-case ASCII letters, numbers, and dashes
- start with a lower-case letter
- end with a lower-case letter or number
- be unique within the set of RestoreChannels in this location If the user does not provide a name, a uuid will be used as the name.
Implementations
Sourceimpl CreateRestoreChannelRequest
impl CreateRestoreChannelRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_restore_channel<T>(self, v: T) -> Selfwhere
T: Into<RestoreChannel>,
pub fn set_restore_channel<T>(self, v: T) -> Selfwhere
T: Into<RestoreChannel>,
Sets the value of restore_channel.
Example
ⓘ
use google_cloud_gkebackup_v1::model::RestoreChannel;
let x = CreateRestoreChannelRequest::new().set_restore_channel(RestoreChannel::default()/* use setters */);Sourcepub fn set_or_clear_restore_channel<T>(self, v: Option<T>) -> Selfwhere
T: Into<RestoreChannel>,
pub fn set_or_clear_restore_channel<T>(self, v: Option<T>) -> Selfwhere
T: Into<RestoreChannel>,
Sets or clears the value of restore_channel.
Example
ⓘ
use google_cloud_gkebackup_v1::model::RestoreChannel;
let x = CreateRestoreChannelRequest::new().set_or_clear_restore_channel(Some(RestoreChannel::default()/* use setters */));
let x = CreateRestoreChannelRequest::new().set_or_clear_restore_channel(None::<RestoreChannel>);Sourcepub fn set_restore_channel_id<T: Into<String>>(self, v: T) -> Self
pub fn set_restore_channel_id<T: Into<String>>(self, v: T) -> Self
Sets the value of restore_channel_id.
Example
ⓘ
let x = CreateRestoreChannelRequest::new().set_restore_channel_id("example");Trait Implementations
Sourceimpl Clone for CreateRestoreChannelRequest
impl Clone for CreateRestoreChannelRequest
Sourcefn clone(&self) -> CreateRestoreChannelRequest
fn clone(&self) -> CreateRestoreChannelRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateRestoreChannelRequest
impl Debug for CreateRestoreChannelRequest
Sourceimpl Default for CreateRestoreChannelRequest
impl Default for CreateRestoreChannelRequest
Sourcefn default() -> CreateRestoreChannelRequest
fn default() -> CreateRestoreChannelRequest
Returns the “default value” for a type. Read more
impl StructuralPartialEq for CreateRestoreChannelRequest